@@ -1,14 +1,11 @@
-
-
-from pkg_resources import resource_string
+from importlib import resources
 
 from yaml import safe_load
 from jsonschema import validate
 
 
 def load_schema():
-    schema = resource_string('showy',
-                             'schema.yaml')
+    schema = resources.files(__package__).joinpath("schema.yaml").read_bytes()
 
     return safe_load(schema)
 
